package nasa.stps.clients;
import nasa.stps.server.StpsServices;
import nasa.stps.server.StatusBlock;
import nasa.stps.core.status.StatusItem;

/**
 * @author Stan Hilinski, June 2001
 */
public class GetStatus
    {
    private static long DELAYMILLIS = 10000L;

    public static void main(String args[])
    {
        String host = (args.length > 0)? args[0] : "localhost server";

        //I hook up via RMI to the STPS server. Its full RMI URL will look
        //something like this: "//host.gsfc.nasa.gov/StpsServices"

        String target = "//" + host + "/StpsServices";
        if (args.length == 2)
        {
            target += "." + args[1];
        }
        
        int cycles = 0;

        try
        {
            StpsServices server = (StpsServices)java.rmi.Naming.lookup(target);

            while (true)
            {
                ++cycles;
                System.out.print("CYCLE=" + cycles);
                String cname = server.getConfigurationName();
                boolean running = server.isEnabled();
                if (running)
                {
                    System.out.print("  running ");
                    System.out.println(cname);
                }
                else if (cname != null)
                {
                    System.out.print("  loaded ");
                    System.out.println(cname);
                }
                else
                {
                    System.out.println("  idle");
                }

                StatusBlock[] blocks = server.getStatus();
                if (blocks != null)
                {
                    for (int n = 0; n < blocks.length; n++)
                    {
                        StatusBlock sb = blocks[n];
                        StatusItem[] si = sb.getStatusItems();
                        System.out.println(sb);
                        for (int k = 0; k < si.length; k++)
                        {
                            System.out.println("    " + si[k]);
                        }
                    }
                }

                Thread.sleep(DELAYMILLIS);
            }
        }
        catch (InterruptedException ie)
        {
            System.err.println(ie);
        }
        catch (java.io.IOException jioe)
        {
            System.err.println(jioe);
        }
        catch (java.rmi.NotBoundException jrnbe)
        {
            System.err.println(jrnbe);
        }
    }
}