package nasa.stps.core;
import java.util.Iterator;

/**
 * StpsNodes that send units to UnitReceivers use this class to broadcast
 * units to more than one UnitReceiver.
 * @author Stan Hilinski, March 2001
 */
public final class UnitBroadcaster extends Broadcaster implements UnitReceiver
{
    /**
     * Create a UnitBroadcaster with an initial two target receivers.
     */
    public UnitBroadcaster(String name, UnitReceiver ur1, UnitReceiver ur2)
    {
        super(name,ur1,ur2);
    }

    /**
     * Give an array of units to this UnitReceiver.
     */
    public void putUnits(Unit[] units) throws StpsException
    {
        Iterator i = output.iterator();
        while (i.hasNext())
        {
            UnitReceiver ur = (UnitReceiver)i.next();
            ur.putUnits(units);
        }
    }

    /**
     * Give a unit to this UnitReceiver.
     */
    public void putUnit(Unit unit) throws StpsException
    {
        if (!unit.isDeleted())
        {
            Iterator i = output.iterator();
            while (i.hasNext())
            {
                UnitReceiver ur = (UnitReceiver)i.next();
                ur.putUnit(unit);
            }
        }
    }
}