package nasa.stps.core;

/**
 * An STPS node that sends units to receivers uses this utility to construct the
 * output object. The utility disguises the fact that the output may be more than
 * one receiver. It also guarantees that all receivers accept units.
 * @author Stan Hilinski, March, 2001
 */
public class UnitOutputTool
{
    private UnitReceiver output = null;
    private UnitBroadcaster broadcaster = null;
    private String name;

    /**
     * Create the unit output tool.
     * @param A name, which is usually the client's name, used in error
     *          messages.
     */
    public UnitOutputTool(String name)
    {
        this.name = name;
    }

    /**
     * Add a UnitReceiver to the output list.
     */
    public void addOutput(UnitReceiver ur)
    {
        if (output == null)
        {
            output = ur;
        }
        else if (broadcaster == null)
        {
            broadcaster = new UnitBroadcaster(name,output,ur);
            output = broadcaster;
        }
        else
        {
            broadcaster.addReceiver(ur);
        }
    }

    /**
     * Add a receiver to the output list.
     * @param node If the receiver is not of the expected type,
     *          then the method throws an exception.
     */
    public void addReceiver(Receiver r) throws StpsException
    {
        if (r instanceof UnitReceiver)
        {
            addOutput((UnitReceiver)r);
        }
        else
        {
            throw new StpsException(name + " sends units to unit receivers; " +
                    r.getLinkName() + " is not a unit receiver.");
        }
    }

    /**
     * Get the constructed unit receiver.
     */
    public UnitReceiver getOutput()
    {
        return output;
    }

    public String toString()
    {
        return name;
    }
}