package nasa.stps.core;

/**
 * Any class that implements UnitReceiver accepts units. This interface
 * is for receivers other than packet and frame receivers. It is used
 * primarily to handle CCSDS services besides the path packet service.
 * @author Stan Hilinski, February 2001
 */
public interface UnitReceiver extends Receiver
{
    /**
     * Give a unit to this UnitReceiver.
     */
    public void putUnit(Unit unit) throws StpsException;

    /**
     * Give an array of units to this UnitReceiver.
     */
    public void putUnits(Unit[] units) throws StpsException;

    /**
     * Flush the data pipeline.
     */
    public void flush() throws StpsException;

    /**
     * Get this receiver's name (for error messages).
     */
    public String getLinkName();
}