package nasa.stps.core.ccsds;
import nasa.stps.core.*;

/**
 * This is the base class for CCSDS service nodes. It receives CADUs (frames).
 * It provides a CADU and CADU-level sequence checking as well as establishing
 * a status item list. It does not assume any sort of output.
 * @author Stan Hilinski, February 2001
 */
public abstract class AbstractService extends StpsNode implements
        FrameReceiver, Cloneable
{
    protected Cadu cadu;
    protected CaduSequencer sequencer;
    protected org.w3c.dom.Element serviceElement;

    /**
     * Construct a service object.
     */
    protected AbstractService(String elementName)
    {
        super(elementName);
    }

    /**
     * Set up this stps node with a configuration.
     */
    public void load(org.w3c.dom.Element element, Configuration configuration)
            throws StpsException
    {
        serviceElement = element;
        String myname = element.getAttribute("label");
        super.setLinkName(myname);
        statusItemList = new java.util.ArrayList(15);
        sequencer = new CaduSequencer(statusItemList);
    }

    /**
     * Finish the setup. When this method is called, you may assume all nodes
     * have been created and exist by name in the map, and all standard links
     * have been resolved. This is a last chance to prepare for data flow.
     */
    public void finishSetup(Configuration configuration) throws StpsException
    {
        /**
         * I must defer creating cadu until after Builder has created all
         * nodes because cadu needs parity lengths from CRC and RS nodes.
         */
        cadu = new Cadu(serviceElement,configuration);
        serviceElement = null;
    }

    /**
     * Give an array of frames to this FrameReceiver.
     */
    public void putFrames(Frame[] frames) throws StpsException
    {
        for (int n = 0; n < frames.length; n++)
        {
            putFrame(frames[n]);
        }
    }
}
