package nasa.stps.core.ccsds;
import nasa.stps.core.StpsException;
import nasa.stps.core.Receiver;

/**
 * An STPS node that sends packets to receivers uses this utility to
 * construct the output object. The utility disguises the fact that the
 * output may be more than one receiver. It also guarantees that all
 * receivers accept packets.
 * @author Stan Hilinski, March, 2001
 */
public class PacketOutputTool
{
    private PacketReceiver output = null;
    private PacketBroadcaster broadcaster = null;
    private String name;

    /**
     * Create the packet receiver tool.
     * @param A name, which is usually the client's name, used in error
     *          messages.
     */
    public PacketOutputTool(String name)
    {
        this.name = name;
    }

    /**
     * Add a PacketReceiver object to the output list.
     */
    public void addOutput(PacketReceiver r)
    {
        if (output == null)
        {
            output = r;
        }
        else if (broadcaster == null)
        {
            broadcaster = new PacketBroadcaster(name,output,r);
            output = broadcaster;
        }
        else
        {
            broadcaster.addReceiver(r);
        }
    }

    /**
     * Add a receiver to the output list.
     * @param node If the receiver is not of the expected type,
     *          then the method throws an exception.
     */
    public void addReceiver(Receiver r) throws StpsException
    {
        if (r instanceof PacketReceiver)
        {
            addOutput((PacketReceiver)r);
        }
        else
        {
            throw new StpsException(name + " sends packets to packet receivers; " +
                    r.getLinkName() + " is not a packet receiver.");
        }
    }

    /**
     * Get the constructed packet receiver.
     */
    public PacketReceiver getOutput()
    {
        return output;
    }

    public String toString()
    {
        return name;
    }
}