package nasa.stps.core.output;
import nasa.stps.core.*;

/**
 * This generic output channel writes units to the output stream. It is
 * also a FrameReceiver, so it can writes frames to an output stream too.
 * @author Stan Hilinski, February 2001
 */
public abstract class AbstractUnitChannel extends AbstractChannel
        implements UnitReceiver, FrameReceiver, Cloneable
{
    /**
     * A constructor.
     */
    protected AbstractUnitChannel(String elementName)
    {
        super(elementName);
    }

    /**
     * Give a unit to this UnitReceiver.
     */
    public abstract void putUnit(Unit unit) throws StpsException;

    /**
     * Give an array of units to this UnitReceiver.
     */
    public final void putUnits(Unit[] units) throws StpsException
    {
        for (int n = 0; n < units.length; n++)
        {
            putUnit(units[n]);
        }
    }

    /**
     * Give a frame to this FrameReceiver.
     */
    public void putFrame(Frame frame) throws StpsException
    {
        putUnit(frame);
    }

    /**
     * Give an array of frames to this FrameReceiver.
     */
    public void putFrames(Frame[] frames) throws StpsException
    {
        for (int n = 0; n < frames.length; n++)
        {
            putUnit(frames[n]);
        }
    }
}