package nasa.stps.core.output;
import nasa.stps.core.StpsException;
import nasa.stps.core.Convert;
import java.io.*;

/**
 * This device writes units to a file.
 * auto-generated file name format:
 * "t" + code + userLabel + currentDateTime + ".dat"
 * code = 'p':packet, 'f':frame, "g":generic unit
 * @author Stan Hilinski, July 2001
 */
class FileDevice extends AbstractOutputDevice
{
    private static java.text.SimpleDateFormat sdf = null;

    FileDevice(org.w3c.dom.Element element, String unitType)
            throws StpsException
    {
        String directory = element.getAttribute("directory");
        String userLabel = element.getAttribute("userLabel");
        String filename = element.getAttribute("filename");

        boolean autoGenerateFilename = Convert.toBoolean(element,
                "autoGenerateFilename",true);

        if (autoGenerateFilename || (filename.length() == 0))
        {
            if (sdf == null)
            {
                sdf = new java.text.SimpleDateFormat("yyyyDDDHHmmss");
            }
            String fdate = sdf.format(new java.util.Date());
            char type = unitType.toLowerCase().charAt(0);
            filename = "t" + type + fdate + userLabel + ".dat";
        }

        try
        {
            File file = new File(directory,filename);
            FileOutputStream os = new FileOutputStream(file);
            BufferedOutputStream bos = new BufferedOutputStream(os,8192);
            output = new DataOutputStream(bos);
        }
        catch (java.io.IOException ioe)
        {
            throw new StpsException(ioe);
        }
    }

    void shutdown() throws StpsException
    {
        try
        {
            output.close();
        }
        catch (java.io.IOException ioe)
        {
            throw new StpsException(ioe);
        }
    }
}
