package nasa.stps.core.output;
import nasa.stps.core.ccsds.*;

/**
 * POST-ANNOTATION, PACKET OUTPUT CHANNEL.
 * This packet output channel writes packets to the output stream. It writes
 * frame and packet annotation immediately after each packet.
 * @author Stan Hilinski, February 2001
 */
public final class PacketChannelB extends AbstractPacketChannel
        implements PacketReceiver, Cloneable
{
    /**
     * This is a class name for this STPS node type. It is not the link name,
     * which is the name of one particular object.
     */
    public static final String CLASSNAME = "PACKET_AFTER";

    /**
     * The constructor.
     */
    public PacketChannelB()
    {
        super(CLASSNAME);
    }

    /**
     * Give a packet to this PacketReceiver.
     */
    public void putPacket(Packet packet) throws nasa.stps.core.StpsException
    {
        if (!packet.isDeleted())
        {
            if (consecutiveErrors == CONSECUTIVE_PERMITTED_ERRORS)
            {
                ++dicardedCount.value;
            }
            else
            {
                try
                {
                    output.write(packet.getData(),0,packet.getSize());
                    writePacketAnnotation(packet);
                    writeFrameAnnotation(packet);
                    ++count.value;
                    consecutiveErrors = 0;
                }
                catch (java.io.IOException e)
                {
                    ++outputErrorCount.value;
                    ++consecutiveErrors;
                }
            }
        }
    }
}
