package nasa.stps.core.output;
import nasa.stps.core.StpsException;
import nasa.stps.core.Convert;
import java.io.*;

/**
 * This device writes units to a tcp/ip socket.
 * @author Stan Hilinski, July 2001
 */
class SocketDevice extends AbstractOutputDevice
{
    private java.net.Socket socket;

    SocketDevice(org.w3c.dom.Element element) throws StpsException
    {
        String host = element.getAttribute("host");
        int port = Convert.toInteger(element,"port",4000);
        int bufferSize = Convert.toInteger(element,"bufferSize",8192);

        try
        {
            socket = new java.net.Socket(host,port);
            int dsize = socket.getSendBufferSize();
            if (bufferSize > dsize)
            {
                socket.setSendBufferSize(bufferSize);
                bufferSize = socket.getSendBufferSize();
            }
            System.out.println("tcp send buffer size. set="+
                    bufferSize + " default=" + dsize);
            OutputStream os = socket.getOutputStream();
            BufferedOutputStream bos =
                    new BufferedOutputStream(os,bufferSize);
            output = new DataOutputStream(bos);
        }
        catch (Exception e)
        {
            throw new StpsException(e);
        }
    }

    void shutdown() throws StpsException
    {
        try
        {
            socket.shutdownOutput();
            output.close();
        }
        catch (java.io.IOException ioe)
        {
            throw new StpsException(ioe);
        }
    }
}
