package nasa.stps.core.xstps;
import nasa.stps.core.*;

/**
 * This class is a special Terra STPS node. It removes Terra's internal PN
 * encoding, which is inside a CADU, starting with the first byte beyond the
 * VCDU header and ending with the byte just before the Reed Solomon parity.
 * @author Stan Hilinski, May 2001
 */
public final class TerraDecoder extends FrameSenderNode implements
        FrameReceiver, Sender, Cloneable
{
    /**
     * This is a class name for this STPS node type, which is also the element
     * name. It is not necessarily the link name, which is the name of one
     * particular object.
     */
    public static final String CLASSNAME = "terra_decoder";

    /**
     * These fields are the start and end byte offsets of the PN-encoded
     * region with the EOS Terra frame.
     */
    private static final int FIRST_BYTE = 10;
    private static final int LAST_BYTE = 1024 - 128;

    /**
     * Create a Terra decoder node.
     */
    public TerraDecoder()
    {
        super(CLASSNAME);
    }

    /**
     * Set up this stps node with a configuration.
     */
    public void load(org.w3c.dom.Element element, Configuration configuration)
            throws StpsException
    {
        String myname = element.getAttribute("label");
        super.setLinkName(myname);
    }

    /**
     * Give a frame to this FrameReceiver.
     */
    public void putFrame(Frame frame) throws StpsException
    {
        if (!frame.isDeleted() && !frame.isFillFrame())
        {
            PnDecoder.decode(frame.getData(),FIRST_BYTE,LAST_BYTE);
            output.putFrame(frame);
        }
    }

    /**
     * Give an array of frames to this FrameReceiver.
     */
    public void putFrames(Frame[] frames) throws StpsException
    {
        for (int n = 0; n < frames.length; n++)
        {
            putFrame(frames[n]);
        }
    }
}
