package nasa.stps.core.xstps.hrit;

/**
 * @author tommyj
 * Sort of a bean class for JPEG decompression info pertaining to an image.
 */

public class DecompressInfo {

    /*
     * Image width, height, and image data precision (bits/sample)
     * These fields are set by ReadFileHeader or ReadScanHeader
     */
    int imageWidth;
    int imageHeight;
    int dataPrecision;

    /*
     * describes component that appears i'th in SOF
     * numComponents is the # of color components in JPEG image.
     * for JMA HRIT, this is always 1
     */
    JpegComponentInfo jci = null;
    
    // For JMA HRIT, num image components is fixed value, set to 1
    int numComponents = 1;

    /*
     * describes component that appears i'th in SOS.
     * compsInScan is the # of color components in current scan.
     * for JMA HRIT, this is always 1
     */
    int compsInScan = 1;

    /*
     * MCUmembership[i] indexes the i'th component of MCU into the
     * curCompInfo array.
     */
    int [] MCUmembership = new int[10];

    /*
     * Huffman coding tables, or NULL if not defined
     */
    HuffmanTable ht = null;

    /*
     * prediction selection value (PSV) and point transform parameter (Pt)
     */
    int Ss;
    int Pt;

    /*
     * In lossless JPEG, restart interval shall be an integer
     * multiple of the number of MCU in a MCU row.
     */
    int restartInterval;/* MCUs per restart interval, 0 = no restart */
    int restartInRows; /*if > 0, MCU rows per restart interval; 0 = no restart*/
    
    /*
     * these fields are private data for the entropy decoder
     */
    int restartRowsToGo;        /* MCUs rows left in this restart interval */
    int nextRestartNum; /* # of next RSTn marker (0..7) */
    
	/**
	 * Constructor
	 */
	public DecompressInfo() {
		super();
		ht = new HuffmanTable();
	}
	
	/**
	 * @return the restartInterval
	 */
	public int getRestartInterval() {
		return restartInterval;
	}
	
	/**
	 * @param restartInterval the restartInterval to set
	 */
	public void setRestartInterval(int restartInterval) {
		this.restartInterval = restartInterval;
	}
	
	/**
	 * @return the imageWidth
	 */
	public int getImageWidth() {
		return imageWidth;
	}
	
	/**
	 * @param imageWidth the imageWidth to set
	 */
	public void setImageWidth(int imageWidth) {
		this.imageWidth = imageWidth;
	}
	
	/**
	 * @return the imageHeight
	 */
	public int getImageHeight() {
		return imageHeight;
	}
	
	/**
	 * @param imageHeight the imageHeight to set
	 */
	public void setImageHeight(int imageHeight) {
		this.imageHeight = imageHeight;
	}
	
	/**
	 * @return the dataPrecision
	 */
	public int getDataPrecision() {
		return dataPrecision;
	}
	
	/**
	 * @param dataPrecision the dataPrecision to set
	 */
	public void setDataPrecision(int dataPrecision) {
		this.dataPrecision = dataPrecision;
	}

	/**
	 * @return the ss
	 */
	public int getSs() {
		return Ss;
	}
	
	/**
	 * @param ss the ss to set
	 */
	public void setSs(int ss) {
		Ss = ss;
	}
	
	/**
	 * @return the pt
	 */
	public int getPt() {
		return Pt;
	}
	
	/**
	 * @param pt the pt to set
	 */
	public void setPt(int pt) {
		Pt = pt;
	}

	/**
	 * @return the compInfo
	 */
	public JpegComponentInfo getCompInfo() {
		return jci;
	}
	
	/**
	 * @param compInfo the compInfo to set
	 */
	public void setCompInfo(JpegComponentInfo jci) {
		this.jci = jci;
	}
	
	/**
	 * @return the restartInRows
	 */
	public int getRestartInRows() {
		return restartInRows;
	}
	
	/**
	 * @param restartInRows the restartInRows to set
	 */
	public void setRestartInRows(int restartInRows) {
		this.restartInRows = restartInRows;
	}
	
	/**
	 * @return the restartRowsToGo
	 */
	public int getRestartRowsToGo() {
		return restartRowsToGo;
	}
	
	/**
	 * @param restartRowsToGo the restartRowsToGo to set
	 */
	public void setRestartRowsToGo(int restartRowsToGo) {
		this.restartRowsToGo = restartRowsToGo;
	}
	
	/**
	 * @return the nextRestartNum
	 */
	public int getNextRestartNum() {
		return nextRestartNum;
	}
	
	/**
	 * @param nextRestartNum the nextRestartNum to set
	 */
	public void setNextRestartNum(int nextRestartNum) {
		this.nextRestartNum = nextRestartNum;
	}
	
	/**
	 * @return the Huffman Table
	 */
	public HuffmanTable getDcHuffTbl() {
		return ht;
	}
	
	/**
	 * @param ht the Huffman Table to set
	 */
	public void setDcHuffTbl(HuffmanTable ht) {
		this.ht = ht;
	}
	
	/**
	 * @return the mCUmembership
	 */
	public int[] getMCUmembership() {
		return MCUmembership;
	}
	
	/**
	 * @param umembership the mCUmembership to set
	 */
	public void setMCUmembership(int[] umembership) {
		MCUmembership = umembership;
	}

}
