package nasa.stps.core.xstps.hrit;

/**
 * @author tommyj
 * Container for data needed for a Huffman table.
 */

public class HuffmanTable {
	
    /* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		StringBuffer sb = new StringBuffer();
		for (int i = 0; i < bits.length; i++) {
			sb.append("Bits[" + i + "]: " + bits[i] + "\n");
		}
		for (int i = 0; i < huffval.length; i++) {
			sb.append("Huffval[" + i + "]: " + huffval[i] + "\n");
		}
		for (int i = 0; i < mincode.length; i++) {
			sb.append("Mincode[" + i + "]: " + mincode[i] + "\n");
		}
		for (int i = 0; i < maxcode.length; i++) {
			sb.append("Maxcode[" + i + "]: " + maxcode[i] + "\n");
		}
		for (int i = 0; i < numbits.length; i++) {
			sb.append("Numbits[" + i + "]: " + numbits[i] + "\n");
		}
		return sb.toString();
	}
	
	/*
     * These two fields directly represent the contents of a JPEG DHT
     * marker
     */
    byte [] bits = new byte[17];
    byte [] huffval = new byte[256];

    /*
     * This field is used only during compression.  It's initialized
     * FALSE when the table is created, and set TRUE when it's been
     * output to the file.
     */
    int sentTable;

    /*
     * The remaining fields are computed from the above to allow more
     * efficient coding and decoding.  These fields should be considered
     * private to the Huffman compression & decompression modules.
     */

    int [] mincode = new int[17];
    int [] maxcode = new int[18];
    int [] valptr = new int[17];
    int [] numbits = new int[256];
    int [] value = new int[256];
    
	/**
	 * @return the bits
	 */
	public byte[] getBits() {
		return bits;
	}
	
	/**
	 * @param bits the bits to set
	 */
	public void setBits(byte[] bits) {
		this.bits = bits;
	}
	
	/**
	 * @return the huffval
	 */
	public byte[] getHuffval() {
		return huffval;
	}
	
	/**
	 * @param huffval the huffval to set
	 */
	public void setHuffval(byte[] huffval) {
		this.huffval = huffval;
	}
	
	/**
	 * @return the sentTable
	 */
	public int getSentTable() {
		return sentTable;
	}
	
	/**
	 * @param sentTable the sentTable to set
	 */
	public void setSentTable(int sentTable) {
		this.sentTable = sentTable;
	}
	
	/**
	 * @return the mincode
	 */
	public int[] getMincode() {
		return mincode;
	}
	
	/**
	 * @param mincode the mincode to set
	 */
	public void setMincode(int[] mincode) {
		this.mincode = mincode;
	}
	
	/**
	 * @return the maxcode
	 */
	public int[] getMaxcode() {
		return maxcode;
	}
	
	/**
	 * @param maxcode the maxcode to set
	 */
	public void setMaxcode(int[] maxcode) {
		this.maxcode = maxcode;
	}
	
	/**
	 * @return the valptr
	 */
	public int[] getValptr() {
		return valptr;
	}
	
	/**
	 * @param valptr the valptr to set
	 */
	public void setValptr(int[] valptr) {
		this.valptr = valptr;
	}
	
	/**
	 * @return the numbits
	 */
	public int[] getNumbits() {
		return numbits;
	}
	
	/**
	 * @param numbits the numbits to set
	 */
	public void setNumbits(int[] numbits) {
		this.numbits = numbits;
	}
	
	public void clearNumbits() {
		for (int i = 0; i < numbits.length; i++) {
			numbits[i] = 0;
		}
	}
	
	/**
	 * @return the value
	 */
	public int[] getValue() {
		return value;
	}
	
	/**
	 * @param value the value to set
	 */
	public void setValue(int[] value) {
		this.value = value;
	}
	
}
