package nasa.stps.core.xstps.hrit;

/**
 * @author tommyj
 * Container for data for a single component of a JPEG transmission.
 */

public class JpegComponentInfo {
    /*
     * These values are fixed over the whole image.
     * They are read from the SOF marker.
     */
    int componentId;            /* identifier for this component (0..255) */
    int componentIndex; /* its index in SOF or cPtr->compInfo[]   */

    /*
     * Downsampling is not normally used in lossless JPEG, although
     * it is permitted by the JPEG standard (DIS). We set all sampling
     * factors to 1 in this program.
     */
    int hSampFactor;            /* horizontal sampling factor */
    int vSampFactor;            /* vertical sampling factor   */

    /*
     * Huffman table selector (0..3). The value may vary
     * between scans. It is read from the SOS marker.
     */
    int dcTblNo;

	/**
	 * @return the componentId
	 */
	public int getComponentId() {
		return componentId;
	}

	/**
	 * @param componentId the componentId to set
	 */
	public void setComponentId(int componentId) {
		this.componentId = componentId;
	}

	/**
	 * @return the componentIndex
	 */
	public int getComponentIndex() {
		return componentIndex;
	}

	/**
	 * @param componentIndex the componentIndex to set
	 */
	public void setComponentIndex(int componentIndex) {
		this.componentIndex = componentIndex;
	}

	/**
	 * @return the hSampFactor
	 */
	public int getHSampFactor() {
		return hSampFactor;
	}

	/**
	 * @param sampFactor the hSampFactor to set
	 */
	public void setHSampFactor(int sampFactor) {
		hSampFactor = sampFactor;
	}

	/**
	 * @return the vSampFactor
	 */
	public int getVSampFactor() {
		return vSampFactor;
	}

	/**
	 * @param sampFactor the vSampFactor to set
	 */
	public void setVSampFactor(int sampFactor) {
		vSampFactor = sampFactor;
	}

	/**
	 * @return the dcTblNo
	 */
	public int getDcTblNo() {
		return dcTblNo;
	}

	/**
	 * @param dcTblNo the dcTblNo to set
	 */
	public void setDcTblNo(int dcTblNo) {
		this.dcTblNo = dcTblNo;
	}
}
