package nasa.stps.core.xstps.pds;
import nasa.stps.core.ccsds.Packet;

/**
 * This class checks for packet sequence gaps. It collects gap information.
 * @author Stan Hilinski, May 2001
 */
class GapList
{
    private Sequencer sequencer;
    private java.util.LinkedList gaplist = new java.util.LinkedList();

    /**
     * This class contains information about one gap.
     */
    class Item
    {
        PacketKernel prePacket = new PacketKernel();
        PacketKernel postPacket = new PacketKernel();
        long datasetOffset = 0;
        int expected = 0;
        int missing = 0;

        Item(int missing, PacketKernel current, PacketKernel previous, long datasetOffset)
        {
            expected = sequencer.getExpectedNextCount();
            this.missing = missing;
            prePacket.copy(previous);
            postPacket.copy(current);
            this.datasetOffset = datasetOffset;
        }
    }

    /**
     * Create a gap list.
     * @param stepsize A non-zero sequence step size.
     */
    GapList(int stepsize)
    {
        sequencer = new Sequencer(stepsize);
    }

    /**
     * Get the number of detected gaps.
     */
    final int getGapCount()
    {
        return gaplist.size();
    }

    /**
     * Check a packet for a gap between it and the previous packet.
     * @return true if a gap was detected
     */
    boolean check(Packet packet, PacketKernel current, PacketKernel previous,
            long datasetOffset)
    {
        boolean seeGap = false;
        int missing = sequencer.check(packet);
        if (missing > 0)
        {
            Item g = new Item(missing,current,previous,datasetOffset);
            gaplist.add(g);
            seeGap = true;
        }
        return seeGap;
    }

    /**
     * Write gap information to the construction record.
     */
    void printCS(java.io.DataOutput out) throws java.io.IOException
    {
        int count = gaplist.size();
        out.writeInt(count);

        java.util.Iterator i = gaplist.iterator();

        while (i.hasNext())
        {
            Item gap = (Item)i.next();
            out.writeInt(gap.expected);
            out.writeLong(gap.datasetOffset);
            out.writeInt(gap.missing);
            out.writeLong(gap.prePacket.getPacketTime());
            out.writeLong(gap.postPacket.getPacketTime());
            out.writeLong(gap.prePacket.getEshTime());
            out.writeLong(gap.postPacket.getEshTime());
        }
    }
}