package nasa.stps.server;

import java.io.FileNotFoundException;
import java.io.IOException;

import nasa.stps.core.StpsException;

/**
 * This interface defines the methods a client like the viewer must use to
 * talk to the server.
 * @author Stan Hilinski, May, 2001
 */
public interface StpsServices
{
    /**
     * Set all clearable status counters to zero.
     */
    public void zeroStatus();

    /**
     * Get the current status from the last-used pipeline. Within a session,
     * the number and identity of the status blocks and the number and
     * identity of the contained status items will not change. Only the
     * status item values may change. However, when a session changes and
     * a new configuration is loaded, then all of these elements will change.
     * @return If no configuration has been loaded into the server, then
     * this method returns null. Otherwise it returns the status of the
     * last created pipeline, even post-session.
     */
    public StatusBlock[] getStatus();

    /**
     * Load a configuration.
     */
    public void load(String configuration) throws StpsException, IOException;

    /**
     * Load a configuration from a file that is local to the server.
     */
    public void loadFile(String file) throws StpsException, IOException, FileNotFoundException;

    /**
     * Enable or disable RLP data processing. This action does not reset the
     * board or change the configuration.
     */
    public void setEnabled(boolean enable);

    /**
     * Unload a configuration, which closes all open data files.
     */
    public void unload() throws StpsException;

    /**
     * Get the name of the currently loaded configuration.
     * @return null if none is loaded.
     */
    public String getConfigurationName();

    /**
     * Is the server loaded and enabled?
     */
    public boolean isEnabled();

    /**
     * Stop the STPS server.
     */
    public void stopServer();
}