package nasa.stps.testing;

import java.util.Iterator;
import java.awt.image.BufferedImage;
import java.awt.image.Raster;
import java.io.*;

import javax.imageio.ImageIO;
import javax.imageio.ImageReader;
import javax.imageio.stream.ImageInputStream;

/**
 * @author Tommy Jasmin, UW SSEC, January 2007
 * This is a standalone test program to decompress the lossless JPEG
 * data from an HRIT image transmission.  It depends on a Java install
 * with both the JAI extension and JAI Image I/O Tools extension.
 */

public class JPEGDecodeTest
{
    public static void main(String args[])
    {
        if (args.length != 1)
        {
            System.err.println("arguments: <datafile>");
            System.exit(1);           
        }

        String datafile = args[0];
        // read in entire tmp JPG file, make image input stream
        File jpegFile = new File(datafile);
        try {
        	ImageInputStream iis = ImageIO.createImageInputStream(jpegFile);
        	Iterator iterator = ImageIO.getImageReaders(iis);
        	if (iterator.hasNext()) {
        		ImageReader ir = (ImageReader) iterator.next();
        		ir.setInput(iis, true);
        		System.out.println("before JPG read...");
        		BufferedImage bi = ir.read(0);
        		System.out.println("BufferedImage width: " + bi.getWidth());
        		System.out.println("BufferedImage height: " + bi.getHeight());
        		Raster r = bi.getData();
        		short [] imageData = (short []) r.getDataElements(0, 0, r.getWidth(), r.getHeight(), null);
        		File outputFile = new File(datafile + "_decompressed");
        		FileOutputStream fos = new FileOutputStream(outputFile);
        		// wrap the file output stream in a data output stream so we can write shorts
        		DataOutputStream dos = new DataOutputStream(fos);
        		// pump out the data
        		for (int i = 0; i < imageData.length; i++) {
        			dos.writeShort(imageData[i]);
        		}
        		dos.close();
        		System.out.println("This file is complete...");
        	} else {
        		System.err.println("Error: Unable to create Iterator of ImageReader objects.");
        	}
        } catch (IOException ioe) {
        	ioe.printStackTrace();
        }

    }
    	
}