package nasa.stps.viewer.bulbs;
import nasa.stps.viewer.commands.CommandStateListener;

/**
 * The ready light is a visual component that shows a light bulb with a label.
 * It shows three colors:<br>
 * gray - The server is unloaded.
 * yellow - The server is loaded but stopped.
 * green - The server is loaded and enabled.
 * @author Stan Hilinski, July 2001
 */
public class ReadyLight extends AbstractBulbGadget implements
        nasa.stps.viewer.commands.CommandStateListener
{
    private static final int MAXCHARS = 9;
    private String configuration = null;

    /**
     * Create a ReadyLight object.
     */
    public ReadyLight(java.awt.Font font)
    {
        super(AbstractBulbGadget.GRAY,"Not Ready",MAXCHARS,font);
        setForeground(java.awt.Color.black);
        setToolTipText("Not Ready/Load/Go Indicator");
        loadBulb(AbstractBulbGadget.YELLOW,"Loaded");
        loadBulb(AbstractBulbGadget.GREEN,"Ready");
    }

    /**
     * ReadyLight is a CommandStateListener.
     */
    public synchronized void commandStateChange(int state)
    {
        String bulbColor = null;
        switch (state)
        {
            case CommandStateListener.UNLOADED:
                bulbColor = AbstractBulbGadget.GRAY;
                break;

            case CommandStateListener.LOADED_STOPPED:
                bulbColor = AbstractBulbGadget.YELLOW;
                break;

            case CommandStateListener.LOADED_GO:
                bulbColor = AbstractBulbGadget.GREEN;
                break;
        }
        if (bulbColor != null)
        {
            final String bcolor = bulbColor;
            java.awt.EventQueue.invokeLater(new Runnable()
            {
                public void run()
                {
                    setBulb(bcolor);
                }
            } );
        }
    }
}

