package nasa.stps.viewer.commands;
import nasa.stps.server.StpsServices;
import javax.swing.JFrame;

/**
 * A special abstract action for go, stop, load, and unload. It sends messages
 * to registered CommandStateListeners when its action is triggered.
 * @author Stan Hilinski, July 2001
 */
abstract class AbstractCommandAction extends nasa.stps.library.XAction
{
    /** The parent JFrame. I use it for error dialogs. */
    protected JFrame frame;
    protected StpsServices server;
    private java.util.LinkedList listeners = new java.util.LinkedList();

    /**
     * Create an AbstractCommandAction.
     */
    protected AbstractCommandAction(String text, JFrame frame,
            StpsServices server)
    {
        super(text);
        this.frame = frame;
        this.server = server;
    }

    /**
     * Create an AbstractCommandAction with an icon.
     */
    protected AbstractCommandAction(String text, JFrame frame,
            StpsServices server, javax.swing.Icon icon)
    {
        super(text,icon);
        this.frame = frame;
        this.server = server;
    }

    /**
     * Notify all listeners of a command state change.
     */
    protected final void notify(int state)
    {
        java.util.Iterator i = listeners.iterator();
        while (i.hasNext())
        {
            CommandStateListener csl = (CommandStateListener)i.next();
            csl.commandStateChange(state);
        }
    }

    /**
     * Add a command state listener.
     */
    void addCommandStateListener(CommandStateListener csl)
    {
        listeners.add(csl);
    }

    /**
     * Remove a command state listener.
     */
    void removeCommandStateListener(CommandStateListener csl)
    {
        listeners.remove(csl);
    }
}