package nasa.stps.viewer.path;
import nasa.stps.viewer.status.Distributor;
import javax.swing.KeyStroke;
import java.awt.event.KeyEvent;
import java.awt.event.InputEvent;

/**
 * This class is an action that causes a new status window to be opened.
 * The window shows all packet status for one application id.
 * <p>
 * I maintain a list of active windows by block name so as to avoid duplicate
 * windows. I become a window listener on each window so that I can remove
 * it from my list of open windows when it closes. It is the window's
 * responsibility to disconnect itself from the Distributor.
 * @author Stan Hilinski, August 2001
 */
public class PacketAction extends StatusWindowAction
{
    public PacketAction(javax.swing.JFrame frame, Distributor distributor)
    {
        super("Packet Status","packet",frame,distributor);
    }

    public final char getMnemonic()
    {
        return 'K';
    }

    public final javax.swing.KeyStroke getKeyStroke()
    {
        return KeyStroke.getKeyStroke(KeyEvent.VK_K,InputEvent.CTRL_MASK);
    }

    public final String getToolTip()
    {
        return "Show all packet status for one application id.";
    }

    protected nasa.stps.viewer.StatusWindow createStatusWindow(
            javax.swing.JFrame frame, String blockName, 
            Distributor distributor)
    {
        return new PacketStatus(frame,blockName,distributor);
    }
}
