package nasa.stps.viewer.tables;
import nasa.stps.viewer.status.Distributor;

/**
 * This class is an abstract table model for my various status tables.
 * @author Stan Hilinski, August 2001
 */
abstract class StatusTableModel extends javax.swing.table.AbstractTableModel
{
    protected String[] header;
    protected java.util.List data = new java.util.ArrayList(64);
    protected Distributor distributor;

    /**
     * Create table model.
     */
    protected StatusTableModel(Distributor distributor)
    {
        this.distributor = distributor;
    }

    /**
     * Create a table row.
     */
    abstract void createRow(int row, String fullBlockName);

    /**
     * Use this method to finish configuration after all rows have been
     * created.
     */
    abstract void configure();

    public final boolean isCellEditable()
    {
        return false;
    }

    public final String getColumnName(int column)
    {
        return header[column];
    }

    public final int getRowCount()
    {
        return data.size();
    }

    public final int getColumnCount()
    {
        return header.length;
    }

    public final Class getColumnClass(int column)
    {
        return String.class;
    }

    public final Object getValueAt(int row, int column)
    {
        StatusRow sr = (StatusRow)data.get(row);
        return sr.getColumnValue(column);
    }

    /**
     * Disconnect the model from the distributor.
     */
    void dispose()
    {
        java.util.Iterator i = data.iterator();
        while (i.hasNext())
        {
            StatusRow sr = (StatusRow)i.next();
            sr.dispose();
        }
    }
}
